@@ -219,7 +219,7 @@ class BaseChunk(object):
             assert data is None and file_obj is None, \
                 'Must specify only path or data or file_obj'
             if os.path.exists(path):
-                ## if the file is there, then use mode 
+                ## if the file is there, then use mode
                 if mode not in ['rb', 'ab']:
                     exc = IOError('mode=%r would overwrite existing %s' % (mode, path))
                     exc.errno = errno.EEXIST
@@ -237,7 +237,7 @@ class BaseChunk(object):
                         ## what to do with stderr
                     else:
                         file_obj = xz.open(path, mode)
-                        
+
                 elif path.endswith('.gz'):
                     assert mode == 'rb', 'mode=%r for .gz' % mode
                     file_obj  = gz.open(path)
@@ -457,7 +457,7 @@ class Chunk(BaseChunk):
         ## read message instances until input buffer is exhausted
         while 1:
 
-            ## instantiate a message  instance 
+            ## instantiate a message  instance
             msg = self.message()
 
             try:
@@ -522,7 +522,7 @@ def decrypt_and_uncompress(data, gpg_private=None, tmp_dir=None,
     '''Given a data buffer of bytes, if gpg_key_path is provided, decrypt
     data using gnupg, and uncompress using `compression` scheme, which
     defaults to "xz" and can also be "gz", "sz", or "".
-    
+
     :returns: a tuple of (logs, data), where `logs` is an array of
       strings and data is a binary string
 
@@ -557,7 +557,7 @@ def decrypt_and_uncompress(data, gpg_private=None, tmp_dir=None,
                 stdin =subprocess.PIPE,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE)
-            ## communicate with child via its stdin 
+            ## communicate with child via its stdin
             data, errors = gpg_child.communicate(data)
             if errors:
                 _errors.append(errors)
@@ -582,7 +582,7 @@ def decrypt_and_uncompress(data, gpg_private=None, tmp_dir=None,
         fh = StringIO(data)
         gz_fh = gz.GzipFile(fileobj=fh, mode='r')
         data = gz_fh.read(data)
-    elif compression == "":
+    elif compression == "" or compression is None:
         ## data is not compressed
         pass
 
@@ -610,7 +610,7 @@ def xz_decompress(data):
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE)
         ## use communicate to pass the data incrementally to the child
-        ## while reading the output, to avoid blocking 
+        ## while reading the output, to avoid blocking
         data, errors = xz_child.communicate(data)
         assert not errors, errors
 
@@ -637,7 +637,7 @@ def xz_compress(data):
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE)
         ## use communicate to pass the data incrementally to the child
-        ## while reading the output, to avoid blocking 
+        ## while reading the output, to avoid blocking
         data, errors = xz_child.communicate(data)
 
         assert not errors, errors
@@ -671,11 +671,11 @@ def compress_and_encrypt(data, gpg_public=None, gpg_recipient='trec-kba',
         gz_fh.write(data)
         gz_fh.close()
         data = fh.getvalue()
-    elif compression == "":
+    elif compression == "" or compression is None:
         pass
 
     if gpg_public is not None:
-        ### setup gpg for encryption.  
+        ### setup gpg for encryption.
         gpg_dir = os.tempnam(tmp_dir, 'tmp-compress-and-encrypt-')
         os.makedirs(gpg_dir)
         try:
@@ -703,7 +703,7 @@ def compress_and_encrypt(data, gpg_public=None, gpg_recipient='trec-kba',
                 stdin =subprocess.PIPE,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE)
-            ## communicate with child via its stdin 
+            ## communicate with child via its stdin
             data, errors = gpg_child.communicate(data)
             if errors:
                 _errors.append(errors)
@@ -714,13 +714,14 @@ def compress_and_encrypt(data, gpg_public=None, gpg_recipient='trec-kba',
     return _errors, data
 
 
+known_compression_schemes = set(['xz', 'gz', 'sz', '', None])
 file_extensions_re = re.compile('.*?(\.(?P<type>(fc|sc)))?(\.(?P<compression>(xz|gz|sz)))?(\.(?P<encryption>gpg))?$')
 
 def parse_file_extensions(path):
     '''accepts a `path` string (can be just a filename) and parses the
     extensions at the end of the file for up to three different
     components:  type.compression.encryption
-    
+
       <name>.<type=(fc|sc)>.<compression=(xz|gz|sz)>.<encryption=gpg>
 
     '''
@@ -749,6 +750,9 @@ def compress_and_encrypt_path(path, gpg_public=None, gpg_recipient='trec-kba',
     _errors = []
     assert os.path.exists(path), path
 
+    if compression is None:
+        compression = ''
+
     commands = {
         'xz': 'xz --compress < ' + path,
         'sz': 'python -m snappy -c < ' + path,
@@ -762,7 +766,7 @@ def compress_and_encrypt_path(path, gpg_public=None, gpg_recipient='trec-kba',
         os.makedirs(tmp_path)
 
     if gpg_public is not None:
-        ### setup gpg for encryption.  
+        ### setup gpg for encryption.
         gpg_dir = os.path.join(tmp_path, 'gpg_dir')
         os.makedirs(gpg_dir)
 
@@ -789,14 +793,14 @@ def compress_and_encrypt_path(path, gpg_public=None, gpg_recipient='trec-kba',
     o_path = os.path.join(tmp_path, 'o_path')
     e_path = os.path.join(tmp_path, 'e_path')
 
-    command += ' 1> ' + o_path 
+    command += ' 1> ' + o_path
 
     logger.debug('compress_and_encrypt_path command %r', command)
     p = subprocess.Popen(command, shell=True, stderr=subprocess.PIPE)
     p_stdout, p_stderr = p.communicate()
     # p_stdout should be empty because we're redirecting to o_path
     if p.returncode != 0:
-        _errors.append('command return code {}'.format(p.retcode))
+        _errors.append('command return code {}'.format(p.returncode))
         _errors.append(p_stderr)
     elif p_stderr:
         # sometimes returncode is zero on failures
